@@ -192,14 +192,6 @@ class ImportAdmin(IDAdmin):
                 elif f_format in ['xlsx', 'xls']:
                     wb = xlrd.open_workbook(file_contents=read_data)
                     df = pd.read_excel(wb)
-
-                    # sheet_0 = wb.sheets()[0]
-                    # row = sheet_0.nrows
-                    # header = sheet_0.row_values(0)
-                    # print(header)
-                    # for i in range(1, row):
-                    #     col = sheet_0.row_values(i)
-                    #     print(col)
                 else:
                     df = None
 
@@ -245,7 +237,7 @@ class ImportAdmin(IDAdmin):
                 return redirect("..")
         except Exception as e:
             self.message_user(request, "导入失败! 错误信息: " + str(e))
-            return redirect(".")
+            return redirect("..")
 
         form = CsvImportForm()
         payload = {"form": form}
